# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MerchantView(BaseModel):
    """
    An array of objects.
    """ # noqa: E501
    access_token: StrictStr = Field(description="The Google merchant access token")
    account_id: Optional[StrictInt] = Field(default=None, description="The account id")
    automatic_synchronization: Optional[StrictBool] = Field(default=None, description="Whether the Merchant data will be synchronized automatically")
    created_at: Optional[datetime] = Field(default=None, description="The create date-time")
    dataset_domain: Optional[StrictStr] = Field(default=None, description="The custom domain (for example data.example.org)")
    dataset_name: Optional[StrictStr] = Field(default=None, description="The dataset path (for example /data)")
    deleted: StrictBool = Field(description="True if the merchant has been deleted")
    deleted_at: Optional[datetime] = Field(default=None, description="The delete date-time")
    google_merchant_id: StrictInt = Field(description="The Google Merchant id")
    id: Optional[StrictInt] = Field(default=None, description="The unique id")
    ignore_brand: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `brand` property during validation")
    ignore_image: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `image` property during validation")
    modified_at: Optional[datetime] = Field(default=None, description="The last modified date-time")
    publisher_name: StrictStr = Field(description="The publisher name (shows in schema publisher)")
    refresh_token: StrictStr = Field(description="The Google merchant refresh token")
    sid: Optional[StrictStr] = None
    sync_has_errors: Optional[StrictBool] = None
    sync_id: Optional[StrictInt] = None
    sync_products_created: Optional[StrictInt] = None
    sync_products_deleted: Optional[StrictInt] = None
    sync_products_errored: Optional[StrictInt] = None
    sync_products_skipped: Optional[StrictInt] = None
    sync_products_total: Optional[StrictInt] = None
    sync_products_updated: Optional[StrictInt] = None
    sync_started_at: Optional[datetime] = Field(default=None, description="The started date-time.")
    sync_stopped_at: Optional[datetime] = Field(default=None, description="The stopped date-time.")
    url: Optional[StrictStr] = Field(default=None, description="The website URL")
    writer_service: Optional[StrictStr] = Field(default=None, description="How to write the merchant data to the graph, if unsure, do not set anything (by default `wordpressMerchantWriter`).")
    __properties: ClassVar[List[str]] = ["access_token", "account_id", "automatic_synchronization", "created_at", "dataset_domain", "dataset_name", "deleted", "deleted_at", "google_merchant_id", "id", "ignore_brand", "ignore_image", "modified_at", "publisher_name", "refresh_token", "sid", "sync_has_errors", "sync_id", "sync_products_created", "sync_products_deleted", "sync_products_errored", "sync_products_skipped", "sync_products_total", "sync_products_updated", "sync_started_at", "sync_stopped_at", "url", "writer_service"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MerchantView from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "account_id",
            "created_at",
            "deleted_at",
            "id",
            "modified_at",
            "sync_started_at",
            "sync_stopped_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MerchantView from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "access_token": obj.get("access_token"),
            "account_id": obj.get("account_id"),
            "automatic_synchronization": obj.get("automatic_synchronization"),
            "created_at": obj.get("created_at"),
            "dataset_domain": obj.get("dataset_domain"),
            "dataset_name": obj.get("dataset_name"),
            "deleted": obj.get("deleted") if obj.get("deleted") is not None else False,
            "deleted_at": obj.get("deleted_at"),
            "google_merchant_id": obj.get("google_merchant_id"),
            "id": obj.get("id"),
            "ignore_brand": obj.get("ignore_brand"),
            "ignore_image": obj.get("ignore_image"),
            "modified_at": obj.get("modified_at"),
            "publisher_name": obj.get("publisher_name"),
            "refresh_token": obj.get("refresh_token"),
            "sid": obj.get("sid"),
            "sync_has_errors": obj.get("sync_has_errors"),
            "sync_id": obj.get("sync_id"),
            "sync_products_created": obj.get("sync_products_created"),
            "sync_products_deleted": obj.get("sync_products_deleted"),
            "sync_products_errored": obj.get("sync_products_errored"),
            "sync_products_skipped": obj.get("sync_products_skipped"),
            "sync_products_total": obj.get("sync_products_total"),
            "sync_products_updated": obj.get("sync_products_updated"),
            "sync_started_at": obj.get("sync_started_at"),
            "sync_stopped_at": obj.get("sync_stopped_at"),
            "url": obj.get("url"),
            "writer_service": obj.get("writer_service")
        })
        return _obj





# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from wordlift_client.models.longtail_response import LongtailResponse
from wordlift_client.models.rank_entities import RankEntities

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class LongTailsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def get2(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> LongtailResponse:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get2_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[LongtailResponse]:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get2_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities

        Query for long tail opportunities and receive entities.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LongtailResponse",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get2_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get3(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get3_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get3_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        hk: Annotated[StrictStr, Field(description="Webhook URL")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities by rank (async)

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param hk: Webhook URL (required)
        :type hk: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get3_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            hk=hk,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get3_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        hk,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if hk is not None:
            
            _query_params.append(('hk', hk))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail/hook',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_v2(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[RankEntities]:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_v2_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[RankEntities]]:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_v2_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="The Longtail query")],
        ln: Annotated[StrictStr, Field(description="A location name, origin of the search")],
        lc: Annotated[StrictStr, Field(description="Language Code")],
        sd: Annotated[StrictStr, Field(description="Search Domain")],
        sc: Annotated[Optional[StrictStr], Field(description="Analysis Scope")] = None,
        d: Annotated[Optional[StrictStr], Field(description="The maximum number of results to analyze")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get entities by rank

        Query for long tail opportunities and receive entities along with their position in SERP.

        :param q: The Longtail query (required)
        :type q: str
        :param ln: A location name, origin of the search (required)
        :type ln: str
        :param lc: Language Code (required)
        :type lc: str
        :param sd: Search Domain (required)
        :type sd: str
        :param sc: Analysis Scope
        :type sc: str
        :param d: The maximum number of results to analyze
        :type d: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_v2_serialize(
            q=q,
            ln=ln,
            lc=lc,
            sd=sd,
            sc=sc,
            d=d,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[RankEntities]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_v2_serialize(
        self,
        q,
        ln,
        lc,
        sd,
        sc,
        d,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if ln is not None:
            
            _query_params.append(('ln', ln))
            
        if lc is not None:
            
            _query_params.append(('lc', lc))
            
        if sd is not None:
            
            _query_params.append(('sd', sd))
            
        if sc is not None:
            
            _query_params.append(('sc', sc))
            
        if d is not None:
            
            _query_params.append(('d', d))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                '*/*'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/longtail/v2',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_website_search import PageWebsiteSearch

class TestPageWebsiteSearch(unittest.TestCase):
    """PageWebsiteSearch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageWebsiteSearch:
        """Test PageWebsiteSearch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageWebsiteSearch`
        """
        model = PageWebsiteSearch()
        if include_optional:
            return PageWebsiteSearch(
                first = '',
                items = [
                    wordlift_client.models.website_search.WebsiteSearch(
                        clicks = 56, 
                        ctr = 1.337, 
                        id = 56, 
                        impressions = 56, 
                        keys = [
                            ''
                            ], 
                        position = 1.337, 
                        score = 1.337, )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageWebsiteSearch(
                first = '',
                items = [
                    wordlift_client.models.website_search.WebsiteSearch(
                        clicks = 56, 
                        ctr = 1.337, 
                        id = 56, 
                        impressions = 56, 
                        keys = [
                            ''
                            ], 
                        position = 1.337, 
                        score = 1.337, )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageWebsiteSearch(self):
        """Test PageWebsiteSearch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generations_api import ContentGenerationsApi


class TestContentGenerationsApi(unittest.TestCase):
    """ContentGenerationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_content_generation(self) -> None:
        """Test case for create_content_generation

        Create
        """
        pass

    def test_delete_content_generation(self) -> None:
        """Test case for delete_content_generation

        Delete
        """
        pass

    def test_duplicate_content_generation(self) -> None:
        """Test case for duplicate_content_generation

        Duplicate
        """
        pass

    def test_get_content_generation(self) -> None:
        """Test case for get_content_generation

        Get
        """
        pass

    def test_list_content_generations(self) -> None:
        """Test case for list_content_generations

        List
        """
        pass

    def test_update_content_generation(self) -> None:
        """Test case for update_content_generation

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.submit_fact_check200_response import SubmitFactCheck200Response

class TestSubmitFactCheck200Response(unittest.TestCase):
    """SubmitFactCheck200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SubmitFactCheck200Response:
        """Test SubmitFactCheck200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SubmitFactCheck200Response`
        """
        model = SubmitFactCheck200Response()
        if include_optional:
            return SubmitFactCheck200Response(
                response = '{
  "@context": "http://schema.org",
  "@type": "ClaimReview",
  "claimReviewed": "Aristotle quote 'It is the mark of an educated mind to be able to entertain a thought without accepting it.'",
  "author": { "@type": "Organization", "name": "WordLift" },
  "datePublished": "2024-01-17",
  "reviewRating": {
    "@type": "Rating",
    "ratingValue": "5",
    "alternateName": "True",
    "bestRating": "5",
    "worstRating": "1"
  },
  "url": "https://fact-check.wordlift.io/review/aristotle-quote",
  "reviewBody": "The quote 'It is the mark of an educated mind to be able to entertain a thought without accepting it.' is correctly attributable to Aristotle. It has been found in multiple credible sources, including publications of academic texts, reputable quote repositories, and philosophical discussions.",
  "itemReviewed": {
    "@type": "CreativeWork",
    "url": ["https://www.azquotes.com/quote/10261", "https://philosiblog.com/2012/03/07/it-is-the-mark-of-an-educated-mind-to-be-able-to-entertain-a-thought-without-accepting-it/", "https://www.brainyquote.com/quotes/aristotle_100584", "https://www.goodreads.com/quotes/1629-it-is-the-mark-of-an-educated-mind-to-be", "https://www.socratic-method.com/philosophy-quote-meanings/aristotle-it-is-the-mark-of-an-educated-mind-to-be-able-to-entertain-a-thought-without-accepting-it"]
  }
}'
            )
        else:
            return SubmitFactCheck200Response(
        )
        """

    def testSubmitFactCheck200Response(self):
        """Test SubmitFactCheck200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from wordlift_client.models.account import Account
from wordlift_client.models.page_active_account import PageActiveAccount
from wordlift_client.models.update_account_request import UpdateAccountRequest

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class AccountsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def get_account(
        self,
        id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Account:
        """Get an account.

        Get the account

        :param id: (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_account_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_account_with_http_info(
        self,
        id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Account]:
        """Get an account.

        Get the account

        :param id: (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_account_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_account_without_preload_content(
        self,
        id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get an account.

        Get the account

        :param id: (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_account_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_account_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/accounts/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_accounts(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Optional[StrictInt] = None,
        can_content_generation: Annotated[Optional[StrictBool], Field(description="Filter accounts that can or cannot do Content Generation")] = None,
        include_entity_count: Annotated[Optional[StrictBool], Field(description="Add entity count data")] = None,
        include_all_accounts: Annotated[Optional[StrictBool], Field(description="Include all the accounts the user has access to")] = None,
        include_subscription: Annotated[Optional[StrictBool], Field(description="Include the subscription data")] = None,
        url: Annotated[Optional[StrictStr], Field(description="The URL")] = None,
        ng_dataset_id: Annotated[Optional[StrictStr], Field(description="The dataset id")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageActiveAccount:
        """List

        List the accounts

        :param cursor: The cursor
        :type cursor: str
        :param limit:
        :type limit: int
        :param can_content_generation: Filter accounts that can or cannot do Content Generation
        :type can_content_generation: bool
        :param include_entity_count: Add entity count data
        :type include_entity_count: bool
        :param include_all_accounts: Include all the accounts the user has access to
        :type include_all_accounts: bool
        :param include_subscription: Include the subscription data
        :type include_subscription: bool
        :param url: The URL
        :type url: str
        :param ng_dataset_id: The dataset id
        :type ng_dataset_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_accounts_serialize(
            cursor=cursor,
            limit=limit,
            can_content_generation=can_content_generation,
            include_entity_count=include_entity_count,
            include_all_accounts=include_all_accounts,
            include_subscription=include_subscription,
            url=url,
            ng_dataset_id=ng_dataset_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageActiveAccount",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_accounts_with_http_info(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Optional[StrictInt] = None,
        can_content_generation: Annotated[Optional[StrictBool], Field(description="Filter accounts that can or cannot do Content Generation")] = None,
        include_entity_count: Annotated[Optional[StrictBool], Field(description="Add entity count data")] = None,
        include_all_accounts: Annotated[Optional[StrictBool], Field(description="Include all the accounts the user has access to")] = None,
        include_subscription: Annotated[Optional[StrictBool], Field(description="Include the subscription data")] = None,
        url: Annotated[Optional[StrictStr], Field(description="The URL")] = None,
        ng_dataset_id: Annotated[Optional[StrictStr], Field(description="The dataset id")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageActiveAccount]:
        """List

        List the accounts

        :param cursor: The cursor
        :type cursor: str
        :param limit:
        :type limit: int
        :param can_content_generation: Filter accounts that can or cannot do Content Generation
        :type can_content_generation: bool
        :param include_entity_count: Add entity count data
        :type include_entity_count: bool
        :param include_all_accounts: Include all the accounts the user has access to
        :type include_all_accounts: bool
        :param include_subscription: Include the subscription data
        :type include_subscription: bool
        :param url: The URL
        :type url: str
        :param ng_dataset_id: The dataset id
        :type ng_dataset_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_accounts_serialize(
            cursor=cursor,
            limit=limit,
            can_content_generation=can_content_generation,
            include_entity_count=include_entity_count,
            include_all_accounts=include_all_accounts,
            include_subscription=include_subscription,
            url=url,
            ng_dataset_id=ng_dataset_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageActiveAccount",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_accounts_without_preload_content(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="The cursor")] = None,
        limit: Optional[StrictInt] = None,
        can_content_generation: Annotated[Optional[StrictBool], Field(description="Filter accounts that can or cannot do Content Generation")] = None,
        include_entity_count: Annotated[Optional[StrictBool], Field(description="Add entity count data")] = None,
        include_all_accounts: Annotated[Optional[StrictBool], Field(description="Include all the accounts the user has access to")] = None,
        include_subscription: Annotated[Optional[StrictBool], Field(description="Include the subscription data")] = None,
        url: Annotated[Optional[StrictStr], Field(description="The URL")] = None,
        ng_dataset_id: Annotated[Optional[StrictStr], Field(description="The dataset id")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List

        List the accounts

        :param cursor: The cursor
        :type cursor: str
        :param limit:
        :type limit: int
        :param can_content_generation: Filter accounts that can or cannot do Content Generation
        :type can_content_generation: bool
        :param include_entity_count: Add entity count data
        :type include_entity_count: bool
        :param include_all_accounts: Include all the accounts the user has access to
        :type include_all_accounts: bool
        :param include_subscription: Include the subscription data
        :type include_subscription: bool
        :param url: The URL
        :type url: str
        :param ng_dataset_id: The dataset id
        :type ng_dataset_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_accounts_serialize(
            cursor=cursor,
            limit=limit,
            can_content_generation=can_content_generation,
            include_entity_count=include_entity_count,
            include_all_accounts=include_all_accounts,
            include_subscription=include_subscription,
            url=url,
            ng_dataset_id=ng_dataset_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PageActiveAccount",
            '401': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_accounts_serialize(
        self,
        cursor,
        limit,
        can_content_generation,
        include_entity_count,
        include_all_accounts,
        include_subscription,
        url,
        ng_dataset_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if can_content_generation is not None:
            
            _query_params.append(('can_content_generation', can_content_generation))
            
        if include_entity_count is not None:
            
            _query_params.append(('include_entity_count', include_entity_count))
            
        if include_all_accounts is not None:
            
            _query_params.append(('include_all_accounts', include_all_accounts))
            
        if include_subscription is not None:
            
            _query_params.append(('include_subscription', include_subscription))
            
        if url is not None:
            
            _query_params.append(('url', url))
            
        if ng_dataset_id is not None:
            
            _query_params.append(('ng_dataset_id', ng_dataset_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/vnd.wordlift.accounts+json;version=1'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/accounts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def update_account(
        self,
        id: StrictInt,
        update_account_request: UpdateAccountRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Account:
        """Update an account.

        Update the account

        :param id: (required)
        :type id: int
        :param update_account_request: (required)
        :type update_account_request: UpdateAccountRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_serialize(
            id=id,
            update_account_request=update_account_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def update_account_with_http_info(
        self,
        id: StrictInt,
        update_account_request: UpdateAccountRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Account]:
        """Update an account.

        Update the account

        :param id: (required)
        :type id: int
        :param update_account_request: (required)
        :type update_account_request: UpdateAccountRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_serialize(
            id=id,
            update_account_request=update_account_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def update_account_without_preload_content(
        self,
        id: StrictInt,
        update_account_request: UpdateAccountRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update an account.

        Update the account

        :param id: (required)
        :type id: int
        :param update_account_request: (required)
        :type update_account_request: UpdateAccountRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_account_serialize(
            id=id,
            update_account_request=update_account_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Account",
            '401': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_account_serialize(
        self,
        id,
        update_account_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_account_request is not None:
            _body_params = update_account_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/accounts/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


